# Overview
**plyball** is a Python package providing a extracting data from several of 
the most popular baseball sources (Fangraphs, Statcast, etc...). A majority 
of these sources are scraped. 

## Where to get it
The source code is currently hosted on GitHub at:
https://github.com/waaronmorris/plyball

Binary installers for the latest released version are available at the [Python
package index](https://pypi.org/project/plyball).

```sh
pip install plyball
```

## Documentation
The official documentation is hosted on ReadtheDocs.org: https://plyball.readthedocs.io/